/*
 * structure.h
 *
 *  Created on: 7 Mar 2020
 *      Author: hinchr
 * Description: forward definition of structures which are referenced by other structures
 */

#ifndef STRUCTURE_H_
#define STRUCTURE_H_

typedef struct interaction interaction;
typedef struct interaction_block interaction_block;
typedef struct infection_event infection_event;
typedef struct event event;
typedef struct event_block event_block;
typedef struct event_list event_list;
typedef struct edge edge;
typedef struct model model;
typedef struct directory directory;
typedef struct trace_token trace_token;
typedef struct trace_token_block trace_token_block;
typedef struct demographic_household_table demographic_household_table;
typedef struct demographic_occupation_network_table demographic_occupation_network_table;
typedef struct strain strain;
typedef struct vaccine vaccine;

#endif /* STRUCTURE_H_ */
